@@ -13,6 +13,7 @@ import unittest
 from mailinglogger.common import RegexConversion
 from mailinglogger.MailingLogger import MailingLogger
 from mailinglogger.SummarisingLogger import SummarisingLogger
+from testfixtures import TempDirectory
 from shared import setUp as shared_setUp
 from shared import tearDown as shared_tearDown
 from tempfile import mkdtemp
@@ -25,17 +26,18 @@ from doctest import DocFileSuite, REPORT_NDIFF,ELLIPSIS
 
 def setUp(test):
     shared_setUp(test)
-    dir = test.globs['dir'] = mkdtemp()
-    os.mkdir(os.path.join(dir,'etc'))
-    test.globs['startdir'] = os.getcwd()
+    tempdir = test.globs['tempdir'] = TempDirectory()
+    tempdir.makedir('etc')
     test.globs['os'] = os
-    test.globs['INSTANCE_HOME'] = dir
-    os.chdir(dir) 
+    test.globs['INSTANCE_HOME'] = tempdir.path
+    test.globs['startdir'] = os.getcwd()
+    os.chdir(tempdir.path)
+
     
 def tearDown(test):
-    shared_tearDown(test)
     os.chdir(test.globs['startdir'])
-    shutil.rmtree(test.globs['dir'])
+    shared_tearDown(test)
+    test.globs['tempdir'].cleanup()
 
 class Tests(unittest.TestCase):
 
@@ -125,6 +127,9 @@ class Tests(unittest.TestCase):
     foo bar
     Baz bob
     </headers>
+    template <before>%s</after>
+    charset     latin-1
+    content_type text/html 
   </mailing-logger>    
         ''')
         # check resulting logger
@@ -145,6 +150,9 @@ class Tests(unittest.TestCase):
                     password='password',
                     ignore=('^MyError(.*)','Foobar'),
                     headers={'foo':'bar','baz':'bob'},
+                    template='<before>%s</after>',
+                    charset='latin-1',
+                    content_type='text/html'
                     )
 
     def test_minimal_config_mailinglogger(self):
@@ -173,6 +181,9 @@ class Tests(unittest.TestCase):
                     password=None,
                     ignore=[],
                     headers={},
+                    template=None,
+                    charset='utf-8',
+                    content_type='text/plain'
                     )
 
     def test_all_keys_summarisinglogger(self):
@@ -194,10 +205,14 @@ class Tests(unittest.TestCase):
     password    password
     ignore      ^MyError(.*)
     ignore      Foobar
+    send_level  error
     <headers>
     foo bar
     Baz bob
     </headers>
+    template <before>%s</after>
+    charset     latin-1
+    content_type text/html
   </summarising-logger>    
         ''')
         # check resulting logger
@@ -208,6 +223,8 @@ class Tests(unittest.TestCase):
                         normal_format='%(levelname)s - %(message)s',
                         date_format='%H:%M:%S on %Y-%m-%d',
                         ignore=('^MyError(.*)','Foobar'),
+                        send_level=logging.ERROR,
+                        charset='latin-1'
                         )
         # check mailer stored as attribure of summariser
         self._checkHandler(l.handlers[0].mailer,
@@ -231,6 +248,9 @@ class Tests(unittest.TestCase):
                            password='password',
                            ignore=[],
                            headers={'foo':'bar','baz':'bob'},
+                           template='<before>%s</after>',
+                           charset='latin-1',
+                           content_type='text/html',
                            )
 
         # Test the ignore setting, which should never be passed to the mailer
@@ -256,6 +276,8 @@ class Tests(unittest.TestCase):
                         normal_format='%(asctime)s - %(levelname)s - %(message)s',
                         date_format='%Y-%m-%dT%H:%M:%S',
                         ignore=[],
+                        send_level=logging.INFO,
+                        charset='utf-8',
                         )
         # check mailer stored as attribure of summariser
         self._checkHandler(l.handlers[0].mailer,
@@ -272,7 +294,10 @@ class Tests(unittest.TestCase):
                            username=None,
                            password=None,
                            ignore=[],
-                           headers={}
+                           headers={},
+                           template=None,
+                           charset='utf-8',
+                           content_type='text/plain'
                            )
         # check atexit
         self.assertEqual(atexit._exithandlers,[(l.handlers[0].close,(),{})])
